@@ -1,8 +1,8 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  * (c)LGPL2+
  *
- * LXDE-Qt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org
+ * LXQt - a lightweight, Qt based, desktop toolset
+ * https://lxqt.org
  *
  * Copyright: 2013 Razor team
  * Authors:
@@ -155,7 +155,8 @@ void MainWindow::on_swap_PB_clicked()
 
 void MainWindow::on_remove_PB_clicked()
 {
-    foreach(const QModelIndex &rowIndex, mSelectionModel->selectedRows())
+    const auto rows = mSelectionModel->selectedRows();
+    for(const QModelIndex &rowIndex : rows)
         mActions->removeAction(mDefaultModel->id(mSortFilterProxyModel->mapToSource(rowIndex)));
 }
 
